%%------------------------------------------------------------------------
% Simulink model of a three-phase Modular Multilevel Converter
% Copyright : Imperix Switzerland ltd 2016
% Engineer : Nicolas Cherix
%% -----------------------------------------------------------------------
clc; close all;


%% Simulation parameters :
tstart = 0;
tstop = 0.4;
tsmax = 5e-5;
tsmin = 1e-6;
rtol = 1e-2;

%% Bus-side parameters :
Vdc = 800;                      % Bus EMF (V)
Rdc = 0.05;                     % Source resistance (ohm)
Ldc = 1e-4;                     % Source inductance (H)

%% Three-phase-side parameters :
Vac_pk = 325;                   % Nominal peak AC amplitude (source EMF) (V)
Rac = 0.01;                     % Source resistance (ohm)
Lac = 2.5e-3;                   % Source inductance (H)
f = 50;                         % Line frequency (Hz)
w = 2*pi*f; 

%% PR controller parameters :
Kp_res = 5;
wc_res = 15;
w_res = 6*w;

%% Submodules parameters :
Csm = 2.7e-3;                   % Submodule capacitance (F)
Rsm = 30e-3;                    % Submodule capacitor ESR (ohm)

%% Branch parameters :
R = 0.05;                       % Parasitic branch resistance (constant part, ohm)
L = 1.0e-3;                     % Branch inductance (self part, H)
M = 0.0e-3;                     % Branch inductance (mutual part, H)

%% Setvalues :
Pref = 4e3;                     % Active power setpoint (W)
Qref = 0000;                    % Reactive power setpoint (Var)
Sref = sqrt(Pref^2 + Qref^2);   % Apparent power setpoint (VA)
phi = atan(Qref/Pref);          % Power factor

Iac_pk_ref = 2/3*Sref/Vac_pk;
Idc_ref = Pref/Vdc;

%% Initial conditions :
Vsm0 = 1.00*Vdc/4;            % Initial value of the cap voltages _U (V)

Iac0_1 = Iac_pk_ref*sin(phi);
Iac0_2 = Iac_pk_ref*sin(phi-2*pi/3);
Iac0_3 = Iac_pk_ref*sin(phi+2*pi/3);

Idc0 = Idc_ref;
Idc0_1 = Idc0/3;
Idc0_2 = Idc0/3;
Idc0_3 = Idc0/3;
